@@ -1,15 +1,16 @@
 #' Scale_colour continuous scheme
 #'
 #' `grafify` internally includes colour-blind compatible schemes for fill and colour/color aesthetics.
-#' Note that this scheme is **only** for continuous variables and has one palette (\code{yellow_conti}) [modified from](http://personal.sron.nl/~pault/#sec:sequential) the YlOrBr scheme from RColorBrewer. 
-#' 
+#' Note that this scheme is **only** for continuous variables and take four options, which include (\code{yellow_conti}) [modified from](http://personal.sron.nl/~pault/#sec:sequential) the YlOrBr scheme from RColorBrewer, `blue_conti`, `PrGn_div` and `OrBl_div`.
+#'  
 #' Colours available can be seen quickly with \code{\link{plot_grafify_palette}}.
 #' 
 #' @param reverse Whether the colour order should be reversed.
+#' @param palette One of five `grafify` palettes for quantiative data `blue_conti`, `yellow_conti`, `grey_conti`, `PrGn_div`, `OrBl_div`
 #' @param ... Additional parameters for `scale_fill` or `scale_colour`.
 #'
 #' @return ggplot scale_fill function for discrete colours.
-#' @export scale_colour_grafify_c
+#' @noRd
 #' @import ggplot2
 #'
 #' @examples
@@ -19,8 +20,9 @@
 #' scale_colour_grafify_c()
 #' 
 
-scale_colour_grafify_c <- function(reverse = FALSE, ...){
-  pal <- graf_col_palette(palette = c("yellow_conti"), 
+scale_colour_grafify_c <- function(palette = c("blue_conti", "yellow_conti", "grey_conti", "PrGn_div", "OrBl_div"), reverse = FALSE, ...){
+  palette <- match.arg(palette)
+  pal <- graf_col_palette(palette = palette, 
                           reverse = reverse)
   scale_color_gradientn(colours = pal(255), ...)
 }
